===============================
venv Context Manager
===============================

.. image:: https://img.shields.io/pypi/v/with-venv.svg
        :target: https://pypi.python.org/pypi/with-venv

.. image:: https://img.shields.io/travis/agodbehere/with-venv.svg
        :target: https://travis-ci.org/agodbehere/with-venv

.. image:: https://readthedocs.org/projects/with-venv/badge/?version=latest
        :target: https://readthedocs.org/projects/with-venv/?badge=latest
        :alt: Documentation Status


Context manager controls venv allowing functions to be run in a different interpreter.

* Free software: ISC license
* Documentation: https://with-venv.readthedocs.org.

Features
--------

* TODO

Credits
---------

This package was created with Cookiecutter_ and the `audreyr/cookiecutter-pypackage`_ project template.

.. _Cookiecutter: https://github.com/audreyr/cookiecutter
.. _`audreyr/cookiecutter-pypackage`: https://github.com/audreyr/cookiecutter-pypackage
